@@ -45,4 +45,12 @@ def set_definition_name_strategy(s):
 
 
 def get_definition_name_strategy():
-	return Config.definition_name_strategy
\ No newline at end of file
+	return Config.definition_name_strategy
+
+
+def set_instantiate_value_provider(p):
+	Config.instantiate_value_provider = p
+
+
+def get_instantiate_value_provider():
+	return Config.instantiate_value_provider
\ No newline at end of file
