@@ -65,6 +65,9 @@ class InstantiateValueProvider:
 							f.definition_name,
 							version=definition.version
 						)
+					if Utils.Empty.isempty(f.default_value) is not True:
+						result[k] = f.default_value
+						continue
 					field_fqn = Config.definition_name_strategy.get_fqn(fqn, k)
 					result[k] = Config.instantiate_value_provider(
 							field_fqn,
@@ -74,6 +77,8 @@ class InstantiateValueProvider:
 							field_definition.get_data_format()
 						)
 				return result
+			if definition.has_default_value() is True:
+				return definition.get_default_value()
 			if definition.is_array():
 				return []
 			if definition.is_nullable() is True:
@@ -471,23 +476,26 @@ class Definition:
 		if model is None:
 			raise Config.exception_factory.create_internal_error(self.data_format.model_name, 'Missing model')
 		fields = {}
-		if isinstance(model, dict):
-			fields = model
-		else:
-			for name in dir(model):
-				if name.startswith('_'):
-					continue
-				fields[name] = getattr(model, name)
-				if fields[name] is None:
-					fields[name] = Schemas.Field(input_name=name, definition_name=name)
-				elif fields[name].definition_name is None:
-					fields[name].definition_name = name
-		for k in fields:
-			f = fields[k]
+		for k in model:
+			f = model[k]
 			if f.input_name is None:
 				f.input_name = k
+			fields[k] = f
 		return fields
 
+	def get_field(self, k):
+		if self.data_type is not DataType.Object:
+			return None
+		model = self.data_format.model
+		if model is None:
+			raise Config.exception_factory.create_internal_error(self.data_format.model_name, 'Missing model')
+		if k not in model:
+			raise Config.exception_factory.create_internal_error(self.data_format.model_name, 'Unkown field: {0}'.format(k))
+		field = model[k]
+		if field.input_name is None:
+			field.input_name = k
+		return field
+
 	def get_boundaries(self):
 		result = []
 		for rule in self.rules:
@@ -504,13 +512,13 @@ class Definition:
 class DefinitionJsonDeserializer:
 	def __init__(self, root):
 		self.namespace = {k:k for k in root}
-		for k in root:
-			if 'aliases' not in root[k]:
-				continue
-			for k1 in root[k]['aliases']:
-				if k1 in self.namespace:
-					raise Config.exception_factory.create_internal_error(k1, 'Input definition already exists.')
-				self.namespace[k1] = k
+		#for k in root:
+			#if 'aliases' not in root[k]:
+			#	continue
+			#for k1 in root[k]['aliases']:
+			#	if k1 in self.namespace:
+			#		raise Config.exception_factory.create_internal_error(k1, 'Input definition already exists.')
+			#	self.namespace[k1] = k
 		self.root = root
 
 	def _get_dict_value(self, idx, k, default_value=Utils.Empty):
@@ -532,8 +540,11 @@ class DefinitionJsonDeserializer:
 		return result
 
 	def _get_definition_name(self, k):
-		result = self.namespace[k]
-		return result
+		if k in self.namespace:
+			result = self.namespace[k]
+			return result
+		d = Index.get(k)
+		return d.get_name()
 
 	def _deserialize_schema_field(self, name, obj):
 		kw = {}
@@ -733,12 +744,16 @@ class Index:
 	_versions = ['base']
 	_versions_idx = {'base': 0}
 	_versions_display_names = {'base': None}
+	_json_dict = {}
 
 	def _resolve_definition_name(definition_or_name, error_on_missing=True):
 		definition_name = definition_or_name
 		if isinstance(definition_or_name, Definition) is True:
 			definition_name = definition_or_name.get_name()
-		resolved = Config.definition_name_resolver.resolve(Index._idx, definition_name)
+		target_ns = Index._idx
+		#if definition_name not in target_ns:
+		#	target_ns = Index._json_dict
+		resolved = Config.definition_name_resolver.resolve(target_ns, definition_name)
 		if resolved is None and error_on_missing is True:
 			raise Config.exception_factory.create_internal_error(
 					definition_name,
@@ -760,6 +775,7 @@ class Index:
 					)
 		latest_version = Index.get_latest_version()
 		for k in Index._idx:
+			Index._ensure_loaded(k)
 			final_definition_version = Index.get_definition_final_version()
 			if Index.compare_versions(final_definition_version, latest_version) < 0:
 				continue
@@ -803,7 +819,9 @@ class Index:
 
 	def list_definition_versions(definition_or_name, include_identical):
 		base_definition = Index.get_definition_base_version(definition_or_name)
-		versions = Index._idx[base_definition.get_name()]
+		base_definition_name = base_definition.get_name()
+		Index._ensure_loaded(base_definition_name)
+		versions = Index._idx[base_definition_name]
 		if include_identical is True:
 			result = [versions[v].get_version() for v in Index._versions if v in versions]
 			return result
@@ -821,6 +839,7 @@ class Index:
 	def get_definition_base_version(definition_or_name):
 		resolved = Index._resolve_definition_name(definition_or_name)
 		for version in Index._versions:
+			Index._ensure_loaded(resolved)
 			if version in Index._idx[resolved]:
 				return Index._idx[resolved][version]
 		raise Config.exception_factory.create_internal_error(
@@ -853,6 +872,16 @@ class Index:
 				'No previous version found (version={0}).'.format(version)
 			)
 
+	def _ensure_loaded(definition_or_name):
+		if isinstance(definition_or_name, Definition):
+			return definition_or_name
+		if Index._idx[definition_or_name] is not None:
+			return Index._idx[definition_or_name]
+		deserializer = DefinitionJsonDeserializer(Index._json_dict)
+		profile = deserializer.deserialize(definition_or_name)
+		Index.register_definition(**profile)
+		return Index._idx[definition_or_name]
+
 	def get(definition_or_name, version=Utils.Empty):
 		definition_name = Index._resolve_definition_name(definition_or_name)
 		if Utils.Empty.isempty(version) is not True:
@@ -861,7 +890,7 @@ class Index:
 						definition_name,
 						'Unknown/unregistered version requested: {0}'.format(version)
 					)
-		versions = Index._idx[definition_name]
+		versions = Index._ensure_loaded(definition_name)
 		# Latest
 		########
 		if Utils.Empty.isempty(version) is True:
@@ -955,12 +984,25 @@ class Index:
 		return result
 
 	def from_json_dict(root):
-		deserializer = DefinitionJsonDeserializer(root)
+		new_entries = {}
 		for k in root:
-			if Index.exists(k):
-				continue
-			profile = deserializer.deserialize(k)
-			Index.register_definition(**profile)
+			new_entries[k] = root[k]
+			if 'aliases' in root[k]:
+				if isinstance(root[k]['aliases'], list):
+					new_entries.update({k1: root[k] for k1 in root[k]['aliases']})
+				else:
+					alias = str(root[k]['aliases'])
+					new_entries[alias] = root[k]
+		for k in new_entries:
+			if k in Index._json_dict or k in Index._idx:
+				raise Config.exception_factory.create_internal_error(
+						k,
+						'Definition registration collision (already defined).'
+					)
+		Index._json_dict.update(new_entries)
+		for k in new_entries:
+			Index._idx[k] = None
+
 
 	def compare_versions(a, b):
 		if a not in Index._versions_idx:
@@ -1080,6 +1122,8 @@ class Index:
 		model = Index._execute_field_init(model, schema.field_init_actions)
 		return model
 
+	t = 0
+
 	def register_definition(
 				name,
 				aliases,
@@ -1157,13 +1201,13 @@ class Index:
 			names.add(aliases)
 		else:
 			names.update(aliases)
-		for entry in names:
-			if entry not in Index._idx:
-				continue
-			raise Config.exception_factory.create_internal_error(
-					entry,
-					'Input definiton already exists.'
-				)
+		#for entry in names:
+		#	if entry not in Index._idx or Index._idx[entry] is None:
+		#		continue
+		#	raise Config.exception_factory.create_internal_error(
+		#			entry,
+		#			'Input definiton already exists.'
+		#		)
 		for entry in names:
 			Index._idx[entry] = definition_versions
 		return Index.get(name, version=final_version)
@@ -1315,3 +1359,4 @@ class Index:
 		Index._data_format_rule_exceptions = set()
 		Index._versions = ['base']
 		Index._versions_idx = {'base': 0}
+		Index._json_dict = {}
