@@ -34,19 +34,7 @@ class Schema:
 			if Utils.Empty.isempty(value):
 				return
 			setattr(self, name, value)
-		obj = None
-		if isinstance(model, dict) is not True:
-			obj = model
-		if isinstance(obj, type):
-			if Utils.Empty.isempty(model_name) is True:
-				model_name = model.__class__.__name__
-			obj = model()
-			model = {}
-			for k in dir(obj):
-				v = getattr(obj, k)
-				if isinstance(v, Field) is True:
-					model[k] = v
-		elif isinstance(model, str):
+		if isinstance(model, str):
 			model = Definitions.Index.get(model, version).data_format.model
 		_set_member('model', model)
 		_set_member('model_name', model_name)
@@ -203,7 +191,7 @@ class Field:
 		_set(result, 'required', self.required)
 		_set(result, 'ignored', self.ignored)
 		_set(result, 'unvalidated', self.unvalidated)
-		_set(result, 'dependency_resolver', self.dependency_resolver)
+		#_set(result, 'dependency_resolver', self.dependency_resolver)
 		_set(result, 'default_value', self.default_value)
 		if 'default_value' in result:
 			default_value_type = Utils.ClassName.class_fqn(self.default_value)
@@ -355,17 +343,7 @@ class ModelValidator:
 		input_names = {}
 		output_field_name_idx = {}
 		default_values = {}
-		fields = {}
-		if isinstance(self.schema.model, dict):
-			fields = self.schema.model
-		else:
-			for entry in dir(self.schema.model):
-				if entry.startswith('__'):
-					continue
-				field = getattr(self.schema.model, entry)
-				if field is not None and isinstance(field, Field) is not True:
-					continue
-				fields[entry] = field
+		fields = self.schema.model
 		for name in fields:
 			field = fields[name]
 			if field is None:
